# Lanelet2 Examples

This package contains executable usage examples for people who would like to know how to work with a lanelet2 map. Simply look at the code in the individual lessons. They are equipped with lots of explaining comments. You can also build and run them to see them in action.

The examples are divided into individual lessons that help you step by step to understand lanelet2. Simply look [here](src) for an overview on the C++ tutorials.

The python tutorials are shorter and demonstrate the similarity of the interface. They can be found [here](scripts/tutorial.py).

